summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/basetreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/basetreeview.h')
-rw-r--r--quanta/treeviews/basetreeview.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/quanta/treeviews/basetreeview.h b/quanta/treeviews/basetreeview.h
index 19e73839..bf7110cf 100644
--- a/quanta/treeviews/basetreeview.h
+++ b/quanta/treeviews/basetreeview.h
@@ -142,21 +142,21 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
* to a KConfig group. Reimplemented to save the open folders.
*
* @param config the KConfig object to write to
* @param group the config group to use
*/
- void saveLayout(KConfig *config, const TQString &group);
+ void saveLayout(TDEConfig *config, const TQString &group);
/**
* Reads the list view's layout from a KConfig group as stored with
* saveLayout. Reimplemented to load the open folders.
*
* @param config the KConfig object to read from
* @param group the config group to use
*/
- void restoreLayout(KConfig *config, const TQString &group);
+ void restoreLayout(TDEConfig *config, const TQString &group);
/**
* en/disable saving a list of open folders in @ref saveLayout and
@@ -182,15 +182,15 @@ protected slots:
void slotCopy();
void slotPaste();
void slotDelete();
- virtual void slotJobFinished( KIO::Job *job);
+ virtual void slotJobFinished( TDEIO::Job *job);
void slotInsertInProject();
void slotInsertDirInProject();
virtual void slotReturnPressed(TQListViewItem *item);
virtual void slotDropped (TQWidget *, TQDropEvent *, KURL::List&, KURL&);
/**
- sends value from KIO::Job to progressbar
+ sends value from TDEIO::Job to progressbar
*/
- virtual void slotPercent(KIO::Job *job, unsigned long value);
+ virtual void slotPercent(TDEIO::Job *job, unsigned long value);
void slotPopulateFinished(KFileTreeViewItem *item);
/**
@@ -142,21 +142,21 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
- * to a KConfig group. Reimplemented to save the open folders.
+ * to a TDEConfig group. Reimplemented to save the open folders.
*
@@ -142,21 +142,21 @@ public:
*
- * @param config the KConfig object to write to
+ * @param config the TDEConfig object to write to
* @param group the config group to use
*/
@@ -142,21 +142,21 @@ public:
/**
- * Reads the list view's layout from a KConfig group as stored with
+ * Reads the list view's layout from a TDEConfig group as stored with
* saveLayout. Reimplemented to load the open folders.
*
@@ -142,21 +142,21 @@ public:
* saveLayout. Reimplemented to load the open folders.
*
- * @param config the KConfig object to read from
+ * @param config the TDEConfig object to read from
* @param group the config group to use
*/